<template>
  <a-card
    title="单据编码列表"
    :bordered="false"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :xl="6"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="单据编码">
              <a-input
                placeholder="请输入单据编码"
                v-model="queryParam.num"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl="6"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="单据名称">
              <a-input
                placeholder="请输入单据名称"
                v-model="queryParam.name"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="10"
            :sm="8"
          >
            <a-form-item label="版本状态">
              <!-- button-style="solid" -->
              <!-- size="small" -->
              <a-radio-group
                @change="onChange"
                default-value="2"
                v-model="queryParam.versionStatus"
              >
                <a-radio-button value="1">
                  未生效
                </a-radio-button>
                <a-radio-button value="2">
                  已生效
                </a-radio-button>
                <a-radio-button value="3">
                  已失效
                </a-radio-button>
              </a-radio-group>
            </a-form-item>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <div class="table-operator">
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增</a-button>
      <!-- v-has="'maintenanceCycle:add'" -->
      <a-button
        type="primary"
        @click="searchQuery"
        icon="search"
      >查询</a-button>
      <a-button
        type="primary"
        @click="searchReset"
        icon="reload"
        style="margin-left: 8px"
      >重置</a-button>
      <!-- <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item
            key="1"
            @click="batchDel"
          ><a-icon type="delete" />删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown> -->
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择
        <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        @change="handleTableChange"
      >
        <!-- :scroll="{ x: 'calc(950px + 50%)', y: 900 }" -->
        <!-- :rowSelection="{ selectedRowKeys: selectedRowKeys, onChange: onSelectChange }" -->
        <span
          slot="action"
          slot-scope="text, record"
        >
          <a
            v-if="record.versionStatus == '2'"
            @click="handleRevise(record)"
          >升版</a>
          <!-- v-has="'maintenanceCycle:revise'" -->
          <a-divider type="vertical" />
          <a
            v-if="record.versionStatus == '1'"
            @click="handleTakeEffect(record)"
          >生效</a>
          <!-- v-has="'maintenanceCycle:takeEffect'" -->
          <a-divider type="vertical" />
          <a
            v-if="record.versionStatus == '1'"
            @click="handleEdit(record)"
          >编辑</a>
          <!-- v-has="'maintenanceCycle:edit'" -->
          <a-divider type="vertical" />
          <a-popconfirm
            v-if="record.versionStatus == '1'"
            title="确定删除吗?"
            @confirm="() => handleDelete(record.id)"
          >
            <!-- v-has="'maintenanceCycle:delete'" -->
            <a>删除</a>
          </a-popconfirm>
        </span>
      </a-table>
    </div>

    <sys-file-name-modal
      ref="modalForm"
      @ok="modalFormOk"
    ></sys-file-name-modal>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import SysFileNameModal from './modules/sysFileName/SysFileNameModal'
import { deleteAction, getAction, postAction, requestPut } from '@/api/manage'

export default {
  name: 'SysFileNameList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    SysFileNameModal,
  },
  data() {
    return {
      description: '单据编码',
      model: {},
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
        },
        {
          title: '单据名称',
          align: 'center',
          dataIndex: 'name_dictText',
        },

        {
          title: '单据编码',
          align: 'center',
          dataIndex: 'num',
        },
        {
          title: '版本',
          align: 'center',
          dataIndex: 'version',
        },
        {
          title: '版本状态',
          align: 'center',
          dataIndex: 'versionStatus_dictText',
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy',
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime',
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' },
        },
      ],
      url: {
        list: '/eam/sysFileName/list',
        delete: '/eam/sysFileName/delete',
        deleteBatch: '/eam/sysFileName/deleteBatch',
        versionTakeEffect: "/eam/sysFileName/versionTakeEffect",
      },
      visible: false,
    }
  },

  methods: {
    //升版
    handleRevise: function (record) {
      this.$refs.modalForm.revise(record);
      this.$refs.modalForm.title = "保养周期规则版本升级";
      this.$refs.modalForm.disableSubmit = false;
    },

    //生效
    handleTakeEffect(record) {
      const that = this;
      that.confirmLoading = true;
      this.$confirm({
        title: '单据编码版本生效！',
        content: '提示：版本生效后上一版本将自动失效，请谨慎操作！',
        okText: '确认',
        cancelText: '取消',
        onOk() {
          requestPut(that.url.versionTakeEffect, { id: record.id, name: record.name, versionStatus: '2' }).then((res) => {
            if (res.success) {
              that.$message.success("版本生效成功！")
              that.loadData(1)
            } else {
              that.$message.warning("版本生效失败！")
            }
          }).finally(() => {
            that.confirmLoading = false;
          })
        },
      })
    },

    onChange(e) {
      this.queryParam.versionStatus = e.target.value;
      this.loadData();
    },

    loadData(arg) {
      if (!this.url.list) {
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }

      var params = this.getQueryParams();//查询条件
      this.loading = true;
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          this.dataSource = res.result.records || res.result;
          if (res.result.total) {
            this.ipagination.total = res.result.total;
          } else {
            this.ipagination.total = 0;
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },
    handleCancel() {
      this.visible = false;
    },
  },
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>